@@ -23,6 +23,7 @@ import (
 	"github.com/superfly/flyctl/internal/client"
 	"github.com/superfly/flyctl/internal/filemu"
 	"github.com/superfly/flyctl/internal/sourcecode"
+	"github.com/superfly/graphql"
 )
 
 func newLaunchCommand(client *client.Client) *Command {
@@ -532,7 +533,7 @@ func appendDockerfileAppendix(appendix []string) (err error) {
 
 	var f *os.File
 	// TODO: we don't flush
-	if f, err = os.OpenFile(dockerfilePath, os.O_APPEND|os.O_WRONLY, 0644); err != nil {
+	if f, err = os.OpenFile(dockerfilePath, os.O_APPEND|os.O_WRONLY, 0600); err != nil {
 		return
 	}
 	defer func() {
@@ -551,7 +552,7 @@ func shouldDeployExistingApp(cmdCtx *cmdctx.CmdContext, appName string) (bool, e
 
 	status, err := cmdCtx.Client.API().GetAppStatus(ctx, appName, false)
 	if err != nil {
-		if api.IsNotFoundError(err) || err.Error() == "Could not resolve App" {
+		if api.IsNotFoundError(err) || graphql.IsNotFoundError(err) {
 			return false, nil
 		}
 		return false, err
